<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh">
<context>
    <name>TxtReader</name>
    <message>
        <location filename="../src/TxtReader.cpp" line="147"/>
        <location filename="../src/TxtReader.cpp" line="256"/>
        <location filename="../src/TxtReader.cpp" line="289"/>
        <source>Page %1 /Total %2</source>
        <translation>第 %1 页/共 %2 页</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="263"/>
        <source>Cannot read file,please contact to author!</source>
        <translation>读取文件错误，请联系作者!</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="545"/>
        <source>&amp;Changes</source>
        <translation>(&amp;C)更新日志</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="272"/>
        <source>TxtReader Changes</source>
        <translation>TxtReader更新日志</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="227"/>
        <source>Read File Failed</source>
        <translation>读取文件失败</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="228"/>
        <source>Failed to read file %1.
Perhaps it is not there, or you don&apos;t have access permission.</source>
        <translation>读取文件%1失败。\n可能文件不存在，或者没有访问权限。</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="277"/>
        <source>&amp;Close</source>
        <translation>(&amp;C)关  闭</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="333"/>
        <source>&amp;GB2312</source>
        <translation>&amp;GB2312</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="339"/>
        <source>&amp;UTF-8</source>
        <translation>&amp;UTF-8</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="345"/>
        <source>&amp;BIG5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="397"/>
        <location filename="../src/TxtReader.cpp" line="512"/>
        <source>&amp;%1 %2</source>
        <translation>&amp;%1 %2</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="412"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="420"/>
        <source>bookmenu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="426"/>
        <source>fontmenu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="432"/>
        <source>bgmenu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="438"/>
        <source>codecmenu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="443"/>
        <source>searchmenu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="447"/>
        <source>hismenu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="531"/>
        <source>Open new file</source>
        <translation>打开新文件</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="531"/>
        <source>text files (*.txt)</source>
        <translation>文本文件 (*.txt)</translation>
    </message>
    <message>
        <source>&lt;p align=center&gt;Txt Reader %1 &lt;/p&gt;&lt;p align=right&gt; Design by &lt;a href=&apos;HOMEPAGE&apos; target=_blank&gt;lsyer&lt;/a&gt;&lt;/p&gt;&lt;p align=center&gt;CopyLeft(C)2006-YEAR&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p align=center&gt;Txt Reader %1 &lt;/p&gt;&lt;p align=right&gt; Design by &lt;a href=&apos;http://code.google.com/p/txtreader4linux/&apos; target=_blank&gt;lsyer&lt;/a&gt;&lt;/p&gt;&lt;p align=center&gt;CopyLeft(C)2006-2011&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="547"/>
        <source>&amp;Back</source>
        <translation>(&amp;B)返  回</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="583"/>
        <source>Jump to:</source>
        <translation>跳转到:</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="595"/>
        <source>Search:</source>
        <translation>搜索:</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="622"/>
        <source>Please input the mark:</source>
        <translation>请输入标签:</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="623"/>
        <location filename="../src/TxtReader.cpp" line="625"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="749"/>
        <source>Select bg-image</source>
        <translation>选择背景图片</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="749"/>
        <source>picture files (*.png *.jpg *.jpeg *.gif)</source>
        <translation>图像文件 (*.png *.jpg *.jpeg *.gif)</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="749"/>
        <source>/home/user/MyDocs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="784"/>
        <source>&amp;Open</source>
        <translation>(&amp;O)打  开</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="785"/>
        <source>&amp;Jump</source>
        <translation>(&amp;J)跳  转</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="788"/>
        <source>&amp;Rotate</source>
        <translation>(&amp;R)旋转屏幕</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="804"/>
        <source>&amp;History</source>
        <translation>(&amp;H)历史</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="786"/>
        <source>&amp;Add Bookmark</source>
        <translation>(&amp;A)添加书签</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="544"/>
        <source>&lt;p align=center&gt;Txt Reader %1 &lt;/p&gt;&lt;p align=center&gt; Design by &lt;a href=&apos;http://code.google.com/p/txtreader4linux&apos; target=_blank&gt;lsyer&lt;/a&gt;&lt;/p&gt;&lt;p align=center&gt;CopyLeft(C)2006-YEAR&lt;/p&gt;&lt;p align=center&gt;Eveing ä¸º N900 ç§»æ¤&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="790"/>
        <source>&amp;Find</source>
        <translation>(&amp;F)查找</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="791"/>
        <source>&amp;Next</source>
        <translation>(&amp;N)下一个</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="792"/>
        <source>&amp;Zoom In</source>
        <translation>(&amp;F)放  大</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="793"/>
        <source>&amp;Zoom Out</source>
        <translation>(&amp;S)缩  小</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="794"/>
        <source>&amp;Set Font</source>
        <translation>(&amp;A)设  置</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="795"/>
        <source>&amp;Color</source>
        <translation>(&amp;C)颜  色</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="797"/>
        <source>&amp;Bg color</source>
        <translation>(&amp;C)颜  色</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="796"/>
        <source>&amp;Screen Light</source>
        <translation>(&amp;L)背  光</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="798"/>
        <source>&amp;Bg image</source>
        <translation>(&amp;B)图  片</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="799"/>
        <source>&amp;Reset</source>
        <translation>(&amp;D)重  设</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="800"/>
        <source>&amp;Quit</source>
        <translation>(&amp;Q)退  出</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="801"/>
        <source>&amp;About</source>
        <translation>(&amp;A)关  于</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="809"/>
        <source>&amp;Search</source>
        <translation>(&amp;S)搜  索</translation>
    </message>
    <message>
        <source>&amp;Instruction</source>
        <translation type="obsolete">(&amp;I)使用指南</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="541"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="229"/>
        <location filename="../src/TxtReader.cpp" line="667"/>
        <location filename="../src/TxtReader.cpp" line="681"/>
        <source>txtreader_%1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="720"/>
        <source>Set Font - Txt Reader %1</source>
        <translation>字体设置 - Txt Reader %1</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="787"/>
        <source>&amp;Del Current</source>
        <translation>(&amp;D)删除当前</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="789"/>
        <source>&amp;Clear All</source>
        <translation>(&amp;C)清除所有</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="803"/>
        <source>&amp;Language</source>
        <translation>&amp;Language</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="805"/>
        <source>&amp;Bookmark</source>
        <translation>(&amp;B)书  签</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="806"/>
        <source>&amp;Font</source>
        <translation>(&amp;F)字  体</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="807"/>
        <source>&amp;Background</source>
        <translation>(&amp;B)背  景</translation>
    </message>
    <message>
        <location filename="../src/TxtReader.cpp" line="808"/>
        <source>&amp;Codec</source>
        <translation>(&amp;C)编  码</translation>
    </message>
    <message>
        <source>&amp;Go Back</source>
        <translation type="obsolete">(&amp;G)返回阅读</translation>
    </message>
</context>
</TS>
